@@ -35,6 +35,7 @@
 #include "brasero-disc.h"
 #include "brasero-uri-container.h"
 #include "brasero-project-type-chooser.h"
+#include "brasero-jacket-edit.h"
 
 G_BEGIN_DECLS
 
@@ -76,7 +77,13 @@ brasero_project_set_source (BraseroProject *project,
 			    BraseroURIContainer *source);
 
 BraseroProjectType
-brasero_project_open_project (BraseroProject *project, const gchar *uri);
+brasero_project_open_playlist (BraseroProject *project,
+			       const gchar *uri);
+
+BraseroProjectType
+brasero_project_open_project (BraseroProject *project,
+			      const gchar *uri);
+
 gboolean
 brasero_project_save_project (BraseroProject *project);
 gboolean
@@ -93,4 +100,8 @@ void
 brasero_project_register_ui (BraseroProject *project,
 			     GtkUIManager *manager);
 
+void
+brasero_project_set_cover_specifics (BraseroProject *project,
+				     BraseroJacketEdit *cover);
+
 #endif /* PROJECT_H */
