@@ -30,6 +30,7 @@
 #include <stdio.h>
 #include <errno.h>
 #include <stdlib.h>
+#include <unistd.h>
 
 #include <glib.h>
 #include <glib-object.h>
@@ -40,19 +41,21 @@
 #include <libisofs/libisofs.h>
 #include <libburn/libburn.h>
 
-#include <libgnomevfs/gnome-vfs.h>
-
 #include "burn-basics.h"
 #include "burn-libburnia.h"
 #include "burn-libisofs.h"
 #include "burn-job.h"
 #include "burn-plugin.h"
+#include "burn-libburn-common.h"
 
 BRASERO_PLUGIN_BOILERPLATE (BraseroLibisofs, brasero_libisofs, BRASERO_TYPE_JOB, BraseroJob);
 
 struct _BraseroLibisofsPrivate {
 	struct burn_source *libburn_src;
 
+	/* that's for multisession */
+	BraseroLibburnCtx *ctx;
+
 	GError *error;
 	GThread *thread;
 	guint thread_id;
@@ -176,7 +179,7 @@ brasero_libisofs_write_image_to_fd_thread (BraseroLibisofs *self)
 	brasero_job_get_fd_out (BRASERO_JOB (self), &fd);
 
 	BRASERO_JOB_LOG (self, "writing to pipe");
-	while (priv->libburn_src->read (priv->libburn_src, buf, sector_size) == sector_size) {
+	while (priv->libburn_src->read_xt (priv->libburn_src, buf, sector_size) == sector_size) {
 		if (priv->cancel)
 			break;
 
@@ -223,7 +226,7 @@ brasero_libisofs_write_image_to_file_thread (BraseroLibisofs *self)
 	priv = BRASERO_LIBISOFS_PRIVATE (self);
 	brasero_job_start_progress (BRASERO_JOB (self), FALSE);
 
-	while (priv->libburn_src->read (priv->libburn_src, buf, sector_size) == sector_size) {
+	while (priv->libburn_src->read_xt (priv->libburn_src, buf, sector_size) == sector_size) {
 		if (priv->cancel)
 			break;
 
@@ -281,6 +284,16 @@ brasero_libisofs_create_image (BraseroLibisofs *self,
 	if (priv->thread)
 		return BRASERO_BURN_RUNNING;
 
+	if (iso_init () < 0) {
+		g_set_error (error,
+			     BRASERO_BURN_ERROR,
+			     BRASERO_BURN_ERROR_GENERAL,
+			     _("Libisofs can't be initialized."));
+		return BRASERO_BURN_ERR;
+	}
+
+	iso_set_msgs_severities ("NEVER", "ALL", "brasero (libisofs)");
+
 	priv->thread = g_thread_create (brasero_libisofs_thread_started,
 					self,
 					TRUE,
@@ -344,16 +357,137 @@ brasero_libisofs_sort_graft_points (gconstpointer a, gconstpointer b)
 	return len_a - len_b;
 }
 
+static int 
+brasero_libisofs_import_read (IsoDataSource *src, uint32_t lba, uint8_t *buffer)
+{
+	struct burn_drive *d;
+	off_t data_count;
+	gint result;
+
+	d = (struct burn_drive*)src->data;
+
+	result = burn_read_data(d,
+				(off_t) lba * (off_t) 2048,
+				(char*)buffer, 
+				2048,
+				&data_count,
+				0);
+	if (result < 0 )
+		return -1; /* error */
+
+	return 1;
+}
+
+static int
+brasero_libisofs_import_open (IsoDataSource *src)
+{
+	return 1;
+}
+
+static int
+brasero_libisofs_import_close (IsoDataSource *src)
+{
+	return 1;
+}
+    
+static void 
+brasero_libisofs_import_free (IsoDataSource *src)
+{ }
+
+static BraseroBurnResult
+brasero_libisofs_import_last_session (BraseroLibisofs *self,
+				      IsoImage *image,
+				      IsoWriteOpts *wopts,
+				      GError **error)
+{
+	int result;
+	IsoReadOpts *opts;
+	BraseroMedia media;
+	IsoDataSource *src;
+	gint64 start_block;
+	gint64 session_block;
+	BraseroLibisofsPrivate *priv;
+
+	priv = BRASERO_LIBISOFS_PRIVATE (self);
+
+	priv->ctx = brasero_libburn_common_ctx_new (BRASERO_JOB (self), error);
+	if (!priv->ctx)
+		return BRASERO_BURN_ERR;
+
+	src = g_new0 (IsoDataSource, 1);
+	src->version = 0;
+	src->refcount = 1;
+	src->read_block = brasero_libisofs_import_read;
+	src->open = brasero_libisofs_import_open;
+	src->close = brasero_libisofs_import_close;
+	src->free_data = brasero_libisofs_import_free;
+	src->data = priv->ctx->drive;
+
+	result = iso_read_opts_new (&opts, 0);
+	if (result < 0) {
+		g_set_error (error,
+			     BRASERO_BURN_ERROR,
+			     BRASERO_BURN_ERROR_GENERAL,
+			     _("No read options could be created."));
+		return BRASERO_BURN_ERR;
+	}
+
+	brasero_job_get_last_session_address (BRASERO_JOB (self), &session_block);
+	iso_read_opts_set_start_block (opts, session_block);
+
+	/* import image */
+	result = iso_image_import (image, src, opts, NULL);
+	iso_data_source_unref (src);
+	iso_read_opts_free (opts);
+
+	/* release the drive */
+	if (priv->ctx) {
+		/* This may not be a good idea ...*/
+		brasero_libburn_common_ctx_free (priv->ctx);
+		priv->ctx = NULL;
+	}
+
+	if (result < 0) {
+		g_set_error (error,
+			     BRASERO_BURN_ERROR,
+			     BRASERO_BURN_ERROR_GENERAL,
+			     _("Image import failed."));	
+		return BRASERO_BURN_ERR;
+	}
+
+	/* check is this is a DVD+RW */
+	brasero_job_get_next_writable_address (BRASERO_JOB (self), &start_block);
+
+	brasero_job_get_media (BRASERO_JOB (self), &media);
+	if (BRASERO_MEDIUM_IS (media, BRASERO_MEDIUM_DVDRW_PLUS)
+	||  BRASERO_MEDIUM_IS (media, BRASERO_MEDIUM_DVDRW_RESTRICTED)
+	||  BRASERO_MEDIUM_IS (media, BRASERO_MEDIUM_DVDRW_PLUS_DL)) {
+		/* This is specific to overwrite media; the start address is the
+		 * size of all the previous data written */
+		BRASERO_JOB_LOG (self, "Growing image (start %i)", start_block);
+	}
+
+	/* set the start block for the multisession image */
+	iso_write_opts_set_ms_block (wopts, start_block);
+	iso_write_opts_set_appendable (wopts, 1);
+
+	iso_tree_set_replace_mode (image, ISO_REPLACE_ALWAYS);
+	return BRASERO_BURN_OK;
+}
+
 static gpointer
 brasero_libisofs_create_volume_thread (gpointer data)
 {
 	BraseroLibisofs *self = BRASERO_LIBISOFS (data);
 	BraseroLibisofsPrivate *priv;
 	BraseroTrack *track = NULL;
-	struct iso_volume *volume;
+	IsoWriteOpts *opts = NULL;
+	IsoImage *image = NULL;
+	BraseroBurnFlag flags;
 	GSList *grafts = NULL;
 	gchar *label = NULL;
 	gchar *publisher;
+	GSList *excluded;
 	GSList *iter;
 
 	priv = BRASERO_LIBISOFS_PRIVATE (self);
@@ -366,18 +500,50 @@ brasero_libisofs_create_volume_thread (gpointer data)
 	BRASERO_JOB_LOG (self, "creating volume");
 
 	/* create volume */
+	brasero_job_get_data_label (BRASERO_JOB (self), &label);
+	if (!iso_image_new (label, &image)) {
+		priv->error = g_error_new (BRASERO_BURN_ERROR,
+					   BRASERO_BURN_ERROR_GENERAL,
+					   _("Volume could not be created."));
+		g_free (label);
+		goto end;
+	}
+
 	publisher = g_strdup_printf ("Brasero-%i.%i.%i",
 				     BRASERO_MAJOR_VERSION,
 				     BRASERO_MINOR_VERSION,
 				     BRASERO_SUB);
 
-	brasero_job_get_data_label (BRASERO_JOB (self), &label);
-	volume = iso_volume_new (label,
-				 publisher,
-				 g_get_real_name ());
+	if (label)
+		iso_image_set_volume_id (image, label);
+
+	iso_image_set_publisher_id (image, publisher);
+	iso_image_set_data_preparer_id (image, g_get_real_name ());
+
 	g_free (publisher);
 	g_free (label);
 
+	iso_write_opts_new (&opts, 2);
+
+	brasero_job_get_flags (BRASERO_JOB (self), &flags);
+	if (flags & BRASERO_BURN_FLAG_MERGE) {
+		BraseroBurnResult result;
+
+		result = brasero_libisofs_import_last_session (self,
+							       image,
+							       opts,
+							       &priv->error);
+		if (result != BRASERO_BURN_OK)
+			goto end;
+	}
+	else if (flags & BRASERO_BURN_FLAG_APPEND) {
+		gint64 start_block;
+
+		brasero_job_get_next_writable_address (BRASERO_JOB (self), &start_block);
+		iso_write_opts_set_ms_block (opts, start_block);
+	}
+
+
 	brasero_job_start_progress (BRASERO_JOB (self), FALSE);
 
 	/* copy the list as we're going to reorder it */
@@ -386,14 +552,23 @@ brasero_libisofs_create_volume_thread (gpointer data)
 	grafts = g_slist_copy (grafts);
 	grafts = g_slist_sort (grafts, brasero_libisofs_sort_graft_points);
 
+	/* add global exclusions */
+	for (excluded = brasero_track_get_data_excluded_source (track, FALSE);
+	     excluded; excluded = excluded->next) {
+		gchar *uri, *local;
+
+		uri = excluded->data;
+		local = g_filename_from_uri (uri, NULL, NULL);
+		iso_tree_add_exclude (image, local);
+		g_free (local);
+	}
+
 	for (iter = grafts; iter; iter = iter->next) {
-		struct iso_tree_node_dir *parent;
-		gchar **excluded_array;
 		BraseroGraftPt *graft;
+		gboolean is_directory;
 		gchar *path_parent;
 		gchar *path_name;
-		GSList *excluded;
-		guint size;
+		IsoNode *parent;
 
 		if (priv->cancel)
 			goto end;
@@ -405,141 +580,152 @@ brasero_libisofs_create_volume_thread (gpointer data)
 				 graft->path,
 				 graft->uri);
 
-		size = g_slist_length (brasero_track_get_data_excluded_source (track, FALSE));
-		size += g_slist_length (graft->excluded);
-		excluded_array = g_new0 (gchar *, size + 1);
-		size = 0;
+		/* search for parent node.
+		 * NOTE: because of mkisofs/genisoimage, we add a "/" at the end
+		 * directories. So make sure there isn't one when getting the 
+		 * parent path or g_path_get_dirname () will return the same
+		 * exact name */
+		if (g_str_has_suffix (graft->path, G_DIR_SEPARATOR_S)) {
+			gchar *tmp;
 
-		/* add global exclusions */
-		for (excluded = brasero_track_get_data_excluded_source (track, FALSE);
-		     excluded; excluded = excluded->next) {
-			gchar *uri;
+			/* remove trailing "/" */
+			tmp = g_strdup (graft->path);
+			tmp [strlen (tmp) - 1] = '\0';
+			path_parent = g_path_get_dirname (tmp);
+			path_name = g_path_get_basename (tmp);
+			g_free (tmp);
 
-			uri = excluded->data;
-			excluded_array [size++] = gnome_vfs_get_local_path_from_uri (uri);
+			is_directory = TRUE;
+		}
+		else {
+			path_parent = g_path_get_dirname (graft->path);
+			path_name = g_path_get_basename (graft->path);
+			is_directory = FALSE;
 		}
 
-		/* now let's take care of the excluded files */
-		for (excluded = graft->excluded; excluded; excluded = excluded->next) {
-			gchar *uri;
-
-			uri = excluded->data;
-			excluded_array [size++] = gnome_vfs_get_local_path_from_uri (uri);
-		}
-
-		/* search for parent node */
-		path_parent = g_path_get_dirname (graft->path);
-		parent = (struct iso_tree_node_dir *) iso_tree_volume_path_to_node (volume, path_parent);
+		iso_tree_path_to_node (image, path_parent, &parent);
 		g_free (path_parent);
 
 		if (!parent) {
 			/* an error has occured, possibly libisofs hasn't been
 			 * able to find a parent for this node */
+			g_free (path_name);
 			priv->error = g_error_new (BRASERO_BURN_ERROR,
 						   BRASERO_BURN_ERROR_GENERAL,
 						   _("a parent for the path (%s) could not be found in the tree"),
 						   graft->path);
-			g_free (excluded_array);
 			goto end;
 		}
 
 		BRASERO_JOB_LOG (self, "Found parent");
-		path_name = g_path_get_basename (graft->path);
 
 		/* add the file/directory to the volume */
 		if (graft->uri) {
 			gchar *local_path;
 
-			local_path = gnome_vfs_get_local_path_from_uri (graft->uri);
+			local_path = g_filename_from_uri (graft->uri, NULL, NULL);
 			if (!local_path){
 				priv->error = g_error_new (BRASERO_BURN_ERROR,
 							   BRASERO_BURN_ERROR_GENERAL,
 							   _("non local file %s"),
 							   G_STRLOC);
-				g_free (excluded_array);
 				g_free (path_name);
 				goto end;
 			}
 
-			if  (g_file_test (local_path, G_FILE_TEST_IS_DIR)) {
-				struct iso_tree_radd_dir_behavior behavior;
+			if  (is_directory) {
+				int result;
+				IsoDir *directory;
 
-				/* first add directory node ... */
-				parent = (struct iso_tree_node_dir *) iso_tree_add_dir (parent, path_name);
-
-				/* ... then its contents */
-				behavior.stop_on_error = 1;
-				behavior.excludes = excluded_array;
-
-				iso_tree_radd_dir (parent,
-						   local_path,
-						   &behavior);
-
-				if (behavior.error) {
-					/* an error has occured, possibly libisofs hasn't been
-					 * able to find a parent for this node */
+				/* add directory node */
+				result = iso_tree_add_new_dir (ISO_DIR (parent), path_name, &directory);
+				if (result < 0) {
 					priv->error = g_error_new (BRASERO_BURN_ERROR,
 								   BRASERO_BURN_ERROR_GENERAL,
-								   _("libisofs reported an error while adding directory %s"),
-								   graft->path);
+								   _("libisofs reported an error while adding directory %s (%x)"),
+								   graft->path,
+								   result);
+					g_free (path_name);
+					goto end;
+				}
+
+				/* add contents */
+				result = iso_tree_add_dir_rec (image, directory, local_path);
+				if (result < 0) {
+					priv->error = g_error_new (BRASERO_BURN_ERROR,
+								   BRASERO_BURN_ERROR_GENERAL,
+								   _("libisofs reported an error while adding contents to directory %s (%x)"),
+								   graft->path,
+								   result);
 					g_free (path_name);
-					g_free (excluded_array);
 					goto end;
 				}
 			}
-			else if (g_file_test (local_path, G_FILE_TEST_IS_REGULAR)) {
-				struct iso_tree_node *node;
-
-				node = iso_tree_add_file (parent, local_path);
-				iso_tree_node_set_name (node, path_name);
-			}
 			else {
-				priv->error = g_error_new (BRASERO_BURN_ERROR,
-							   BRASERO_BURN_ERROR_GENERAL,
-							   _("unsupported type of file (at %s)"),
-							   G_STRLOC);
-				g_free (path_name);
-				g_free (excluded_array);
-				goto end;
+				IsoNode *node;
+
+				if (iso_tree_add_node (image, ISO_DIR (parent), local_path, &node) < 0) {
+					priv->error = g_error_new (BRASERO_BURN_ERROR,
+								   BRASERO_BURN_ERROR_GENERAL,
+								   _("libisofs reported an error while adding file %s"),
+								   graft->path);
+					g_free (path_name);
+					goto end;
+				}
+				iso_node_set_name (node, path_name);
 			}
 
 			g_free (local_path);
 		}
-		else
-			iso_tree_add_dir (parent, path_name);
+		else if (iso_tree_add_new_dir (ISO_DIR (parent), path_name, NULL) < 0) {
+			priv->error = g_error_new (BRASERO_BURN_ERROR,
+						   BRASERO_BURN_ERROR_GENERAL,
+						   _("libisofs reported an error while creating directory %s"),
+						   graft->path);
+			g_free (path_name);
+			goto end;
+
+		}
 
 		g_free (path_name);
-		g_free (excluded_array);
 	}
 
+
 end:
 
-	if (iter)
-		g_slist_free (iter);
+	if (grafts)
+		g_slist_free (grafts);
 
 	if (!priv->error && !priv->cancel) {
 		gint64 size;
 		BraseroTrackType type;
-		struct iso_volset *volset;
-		struct ecma119_source_opts opts;
 
 		brasero_track_get_type (track, &type);
-		volset = iso_volset_new (volume, "VOLSETID");
 
-		memset (&opts, 0, sizeof (struct ecma119_source_opts));
-		opts.level = 2;
-		opts.relaxed_constraints = ECMA119_NO_DIR_REALOCATION;
-		opts.flags = ((type.subtype.img_format & BRASERO_IMAGE_FS_JOLIET) ? ECMA119_JOLIET : 0);
-		opts.flags |= ECMA119_ROCKRIDGE;
+		if ((type.subtype.fs_type & BRASERO_IMAGE_FS_ISO)
+		&&  (type.subtype.fs_type & BRASERO_IMAGE_ISO_FS_LEVEL_3))
+			iso_write_opts_set_iso_level (opts, 3);
+		else
+			iso_write_opts_set_iso_level (opts, 2);
 
-		priv->libburn_src = iso_source_new_ecma119 (volset, &opts);
+		iso_write_opts_set_rockridge (opts, 1);
+		iso_write_opts_set_joliet (opts, (type.subtype.img_format & BRASERO_IMAGE_FS_JOLIET) != 0);
+		iso_write_opts_set_allow_deep_paths (opts, (type.subtype.fs_type & BRASERO_IMAGE_ISO_FS_DEEP_DIRECTORY) != 0);
 
-		size = priv->libburn_src->get_size (priv->libburn_src);
-		brasero_job_set_output_size_for_current_track (BRASERO_JOB (self),
-							       BRASERO_SIZE_TO_SECTORS (size, 2048),
-							       size);
+		if (iso_image_create_burn_source (image, opts, &priv->libburn_src) >= 0) {
+			size = priv->libburn_src->get_size (priv->libburn_src);
+			brasero_job_set_output_size_for_current_track (BRASERO_JOB (self),
+								       BRASERO_SIZE_TO_SECTORS (size, 2048),
+								       size);
+		}
 	}
 
+	if (opts)
+		iso_write_opts_free (opts);
+
+	if (image)
+		iso_image_unref (image);
+
 	if (!priv->cancel)
 		priv->thread_id = g_idle_add (brasero_libisofs_create_volume_thread_finished, self);
 
@@ -558,6 +744,15 @@ brasero_libisofs_create_volume (BraseroLibisofs *self, GError **error)
 	if (priv->thread)
 		return BRASERO_BURN_RUNNING;
 
+	if (iso_init () < 0) {
+		g_set_error (error,
+			     BRASERO_BURN_ERROR,
+			     BRASERO_BURN_ERROR_GENERAL,
+			     _("Libisofs can't be initialized."));
+		return BRASERO_BURN_ERR;
+	}
+
+	iso_set_msgs_severities ("NEVER", "ALL", "brasero (libisofs)");
 	priv->thread = g_thread_create (brasero_libisofs_create_volume_thread,
 					self,
 					TRUE,
@@ -601,6 +796,19 @@ brasero_libisofs_stop_real (BraseroLibisofs *self)
 	BraseroLibisofsPrivate *priv;
 
 	priv = BRASERO_LIBISOFS_PRIVATE (self);
+
+	/* NOTE: this can only happen when we're preparing the volumes for a
+	 * multi session disc. At this point we're only running to get the size
+	 * of the future volume and we can't race with libburn plugin that isn't
+	 * operating at this stage. */
+	if (priv->ctx) {
+		brasero_libburn_common_ctx_free (priv->ctx);
+		priv->ctx = NULL;
+	}
+
+	if (priv->libburn_src)
+		priv->libburn_src->cancel (priv->libburn_src);
+
 	if (priv->thread) {
 		priv->cancel = 1;
 		g_thread_join (priv->thread);
@@ -658,6 +866,13 @@ brasero_libisofs_clean_output (BraseroLibisofs *self)
 		burn_source_free (priv->libburn_src);
 		priv->libburn_src = NULL;
 	}
+
+	/* Since the library is not needed any more call burn_finish ().
+	 * NOTE: it itself calls burn_abort (). */
+	burn_finish ();
+
+	/* close libisofs library */
+	iso_finish ();
 }
 
 static void
@@ -685,6 +900,30 @@ brasero_libisofs_export_caps (BraseroPlugin *plugin, gchar **error)
 			       "Philippe Rouquier",
 			       0);
 
+	/* NOTE: we don't include DVDRW+ DVDRW- restricted in here */
+	brasero_plugin_set_flags (plugin,
+				  BRASERO_MEDIUM_CDR|
+				  BRASERO_MEDIUM_CDRW|
+				  BRASERO_MEDIUM_DVDR|
+				  BRASERO_MEDIUM_DVDRW|
+				  BRASERO_MEDIUM_DVD_DL|
+				  BRASERO_MEDIUM_APPENDABLE|
+				  BRASERO_MEDIUM_HAS_AUDIO|
+				  BRASERO_MEDIUM_HAS_DATA,
+				  BRASERO_BURN_FLAG_APPEND|
+				  BRASERO_BURN_FLAG_MERGE,
+				  BRASERO_BURN_FLAG_NONE);
+
+	brasero_plugin_set_flags (plugin,
+				  BRASERO_MEDIUM_DVDRW_PLUS|
+				  BRASERO_MEDIUM_RESTRICTED|
+				  BRASERO_MEDIUM_DVD_DL|
+				  BRASERO_MEDIUM_APPENDABLE|
+				  BRASERO_MEDIUM_CLOSED|
+				  BRASERO_MEDIUM_HAS_DATA,
+				  BRASERO_BURN_FLAG_MERGE,
+				  BRASERO_BURN_FLAG_NONE);
+
 	output = brasero_caps_image_new (BRASERO_PLUGIN_IO_ACCEPT_FILE|
 					 BRASERO_PLUGIN_IO_ACCEPT_PIPE,
 					 BRASERO_IMAGE_FORMAT_BIN);
